# Generated by Django 2.2 on 2023-05-05 05:52

import django.contrib.postgres.fields.jsonb
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('wcd_envoyer', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='message',
            options={'ordering': ('-created_at',), 'verbose_name': 'Message', 'verbose_name_plural': 'Messages'},
        ),
        migrations.CreateModel(
            name='TemplateTranslation',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='ID')),
                ('language', models.CharField(choices=[('ru', 'Russian'), ('uk', 'Ukrainian'), ('pl', 'Polish'), ('cs', 'Czech'), ('ru-md', 'Russian-md'), ('ru-uz', 'Russian-uz'), ('cs-sk', 'Czech-sk'), ('ro', 'Romanian')], default='ru', max_length=32, verbose_name='Language')),
                ('data', django.contrib.postgres.fields.jsonb.JSONField(default=dict, verbose_name='Data')),
                ('entity', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='translations', to='wcd_envoyer.Template', verbose_name='Translation entity')),
            ],
            options={
                'base_manager_name': 'objects',
                'unique_together': {('language', 'entity')},
            },
        ),
    ]
